/*
 *  Copyright 2016 Anyware Services
 *
 *  Licensed under the Apache License, Version 2.0 (the "License");
 *  you may not use this file except in compliance with the License.
 *  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 *  Unless required by applicable law or agreed to in writing, software
 *  distributed under the License is distributed on an "AS IS" BASIS,
 *  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 *  See the License for the specific language governing permissions and
 *  limitations under the License.
 */

Ext.namespace('org.ametys.user.directory');

org.ametys.user.directory.UserDirectoryRootButton = function(id, configuration, pluginName) 
{
	org.ametys.user.directory.UserDirectoryRootButton.superclass.constructor.call(this, id, configuration, pluginName);
};

Ext.extend(org.ametys.user.directory.UserDirectoryRootButton, org.ametys.ribbon.control.button.ActionButton, {});

org.ametys.user.directory.UserDirectoryRootButton.prototype._currentPageId;

org.ametys.user.directory.UserDirectoryRootButton.prototype.onMessage = function (messages)
{
	// SELECTION
	for (var i=messages.length - 1; i >= 0; i--)
	{
		if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_SELECTIONCHANGED)
		{
			var targets = messages[i].getTargets();
			var allTargets = org.ametys.messagebus.message.MessageTargetHelper.findAll(targets, function (target) { return target.getType() == 'page'});
			
			if (allTargets.length == 0)
			{
				// No page selected
				this.getElements().each(function(element) { element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["no-page"]);
				
				this._currentPageId = null;
			}
			else if (allTargets.length > 1)
			{
				// Too many pages selected
				this.getElements().each(function(element) { element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["too-many-pages"]);
				
				this._currentPageId = null;
			}
			else
			{
				if (this._currentPageId != allTargets[0].getParameters().id)
				{
					this.getElements().each(function(element) { element.refreshing(); element.setDisabled(true); });
					this.updateTooltip(this.getConfiguration()["default-description"]);
					org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: allTargets[0].getParameters().id});
				}
			}
			
			return;
		}
		else if (messages[i].getType().getName() == "metadataChanging")
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function (target) { return target.getType() == 'page'});
			
			if (target != null && this._currentPageId == target.getParameters().id)
			{
				this.getElements().each(function(element) { element.refreshing(); element.setDisabled(true); });
			}
		}
		else if (messages[i].getType().getName() == org.ametys.ribbon.RibbonManager.EVENTTYPE_METADATACHANGED)
		{
			var targets = messages[i].getTargets();
			var target = org.ametys.messagebus.message.MessageTargetHelper.findFirst(targets, function (target) { return target.getType() == 'page'});
			
			if (target != null && this._currentPageId == target.getParameters().id)
			{
				this.getElements().each(function(element) { element.refreshing(); element.setDisabled(true); });
				this.updateTooltip(this.getConfiguration()["default-description"]);
				org.ametys.ribbon.RibbonManager.getInstance().refreshElement('control', this, {target: target.getParameters().id});
			}
		}
	}
}

org.ametys.user.directory.UserDirectoryRootButton.prototype.configurationError = function(response)
{
	this.getElements().each(function(element) { element.stopRefreshing(); element.setDisabled(true); });
	this.updateTooltip(this.getConfiguration()["default-description"]);
}

org.ametys.user.directory.UserDirectoryRootButton.prototype.configurationChanged = function(params)
{
	this.getElements().each(function(element) { element.stopRefreshing(); });
	
	var tooltip = this._getTooltip("", params);
	
	var hasOnePage = tooltip.length > 0; 
	if (!hasOnePage)
	{
		tooltip += this.getConfiguration()['no-page'];
	}
	
	var disabledState = this._isDisabled(params);
	var toggleState = this._isToggle(params);
	this._toggleState = toggleState;
	this.getElements().each(function(element) { element.setDisabled(!hasOnePage || disabledState); });
	this.getElements().each(function(element) { element.toggle(toggleState); });
	this.updateTooltip(tooltip);
	
	this._lastParams = params;
}
org.ametys.user.directory.UserDirectoryRootButton.prototype.getCurrentParameters = function()
{
	return this._lastParams;
}

org.ametys.user.directory.UserDirectoryRootButton.prototype._isDisabled = function(params)
{
    return params['no-jcr-page-id'] != null;
}

org.ametys.user.directory.UserDirectoryRootButton.prototype._isToggle = function(params)
{
	return params['user-directory-page-id'] != null;
}

org.ametys.user.directory.UserDirectoryRootButton.prototype._getTooltip = function(tooltip, params)
{
	if (params['user-directory-page-id'])
	{
		tooltip += this.getConfiguration()["user-directory-page-start-description"];
		tooltip += params["user-directory-page-title"];
		tooltip += this.getConfiguration()["user-directory-page-end-description"];
		
		if (params["population-user-directory-page-description"] != null)
		{
			tooltip += " ";
			tooltip += params["population-user-directory-page-description"];
		}
	
		tooltip += "<br/><br/>";
		
		tooltip += this.getConfiguration()["remove-user-directory-page-start-description"];
		tooltip += params["remove-user-directory-page-title"];
		tooltip += this.getConfiguration()["remove-user-directory-page-end-description"];
		
		this._currentPageId = params['user-directory-page-id'];
	}
	else if (params['no-jcr-page-id'])
	{
		tooltip += this.getConfiguration()["no-jcr-page-start-description"];
		tooltip += params["no-jcr-page-title"];
		tooltip += this.getConfiguration()["no-jcr-page-end-description"];
		
		this._currentPageId = null;
	}
	else
	{
		tooltip += this.getConfiguration()["add-user-directory-page-start-description"];
		tooltip += params["add-user-directory-page-title"];
		tooltip += this.getConfiguration()["add-user-directory-page-end-description"];
		
		this._currentPageId = params['add-user-directory-page-id'];
	}
	return tooltip;
}